@@ -1,19 +1,18 @@
 #' Plot GTFS stops and trips
 #'
-#' @param x a gtfs_obj as read by read_gtfs()
-#' @param ... further specifications
+#' @param x a tidygtfs object as read by [read_gtfs()]
+#' @param ... ignored for tidygtfs
 #' @return plot
 #'
 #' @examples \donttest{
 #' local_gtfs_path <- system.file("extdata",
-#'                               "google_transit_nyc_subway.zip",
+#'                               "nyc_subway.zip",
 #'                               package = "tidytransit")
 #' nyc <- read_gtfs(local_gtfs_path)
 #' plot(nyc)
 #' }
 #' 
 #' @importFrom graphics plot
-#' @importFrom dplyr select
 #' @export
 plot.tidygtfs <- function(x, ...) {
   dots <- list(...)
@@ -21,9 +20,9 @@ plot.tidygtfs <- function(x, ...) {
     stop("Feed doesn't contain a stops table")
   }
   x_stops <- x$stops 
-  if(!"sf" %in% class(x$stops))  x_stops <- stops_as_sf(x$stops)
+  if(!inherits(x$stops, "sf"))  x_stops <- stops_as_sf(x$stops)
 
-  if("sf" %in% class(x$shapes)) {
+  if(inherits(x$shapes, "sf")) {
     plot(x$shapes["shape_id"], reset = FALSE, main = agency_info(x))
     plot(x_stops[,"stop_id"], add = TRUE)
   } else {
