@@ -55,12 +55,13 @@
 #' # should raise a warning
 #' gtfs$stop_times <- NULL
 #' validation_result <- validate_gtfs(gtfs)
-#' }
+#' } 
+#' @importFrom dplyr as_tibble
 #' @export
 validate_gtfs <- function(gtfs_obj, files = NULL, warnings = TRUE) {
   
   # input checking
-  if(!inherits(gtfs_obj, "gtfs") & !inherits(gtfs_obj, "list")) {
+  if(!inherits(gtfs_obj, "gtfs") && !inherits(gtfs_obj, "list")) {
     stop("gtfs_obj must be a gtfs or list object")
   }
   
@@ -186,7 +187,7 @@ validate_gtfs <- function(gtfs_obj, files = NULL, warnings = TRUE) {
   # raises warnings if problems are found
   files_problems <- validation_result[validation_details == "missing_req_file"]
   
-  if(nrow(files_problems) >= 1 & warnings) {
+  if(nrow(files_problems) >= 1 && warnings) {
     
     warning(
       paste0(
@@ -200,7 +201,7 @@ validate_gtfs <- function(gtfs_obj, files = NULL, warnings = TRUE) {
 
   fields_problems <- validation_result[validation_details == "missing_req_field"]
   
-  if(nrow(fields_problems) >= 1 & warnings) {
+  if(nrow(fields_problems) >= 1 && warnings) {
     problematic_files <- unique(fields_problems$file)
     
     problematic_fields <- unlist(
@@ -222,8 +223,7 @@ validate_gtfs <- function(gtfs_obj, files = NULL, warnings = TRUE) {
     
   }
 
-  # attach validation_result as an attribute of the given gtfs
-  dplyr::as_tibble(validation_result)
+  as_tibble(validation_result)
 }
 
 #' Check if primary keys are unique within tables
